[SCM] WebKit Debian packaging branch, debian/experimental, updated. upstream/1.3.3-9427-gc2be6fc

tkent at chromium.org tkent at chromium.org
Wed Dec 22 11:32:57 UTC 2010


The following commit has been merged in the debian/experimental branch:
commit bb1ecd2316b69b6f6fd7e4cde5198a0525a1b619
Author: tkent at chromium.org <tkent at chromium.org@268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Thu Jul 29 00:56:53 2010 +0000

    [Chromium] Improve read-only arrow button appearance
    https://bugs.webkit.org/show_bug.cgi?id=43108
    
    Reviewed by Darin Fisher.
    
    No new tests. This is a fix for fast/forms/
    input-appearance-spinbutton-disabled-readonly.html
    
    * platform/chromium/PlatformThemeChromiumGtk.cpp:
    (WebCore::PlatformThemeChromiumGtk::paintArrowButton):
    If the button has ReadOnlyState, paint the button as same as it is disabled.
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@64250 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebCore/ChangeLog b/WebCore/ChangeLog
index 12336ce..b458a52 100644
--- a/WebCore/ChangeLog
+++ b/WebCore/ChangeLog
@@ -1,3 +1,17 @@
+2010-07-28  Kent Tamura  <tkent at chromium.org>
+
+        Reviewed by Darin Fisher.
+
+        [Chromium] Improve read-only arrow button appearance
+        https://bugs.webkit.org/show_bug.cgi?id=43108
+
+        No new tests. This is a fix for fast/forms/
+        input-appearance-spinbutton-disabled-readonly.html
+
+        * platform/chromium/PlatformThemeChromiumGtk.cpp:
+        (WebCore::PlatformThemeChromiumGtk::paintArrowButton):
+        If the button has ReadOnlyState, paint the button as same as it is disabled.
+
 2010-07-28  Tony Chang  <tony at chromium.org>
 
         Reviewed by Ojan Vafai.
diff --git a/WebCore/platform/chromium/PlatformThemeChromiumGtk.cpp b/WebCore/platform/chromium/PlatformThemeChromiumGtk.cpp
index 1f74840..6529482 100644
--- a/WebCore/platform/chromium/PlatformThemeChromiumGtk.cpp
+++ b/WebCore/platform/chromium/PlatformThemeChromiumGtk.cpp
@@ -180,8 +180,8 @@ void PlatformThemeChromiumGtk::paintArrowButton(GraphicsContext* gc, const IntRe
     paint.setColor(outlineColor(trackHSV, thumbHSV));
     canvas->drawPath(outline, paint);
 
-    // If the button is disabled, the arrow is drawn with the outline color.
-    if (states & EnabledState)
+    // If the button is disabled or read-only, the arrow is drawn with the outline color.
+    if (states & EnabledState && !(states & ReadOnlyState))
         paint.setColor(SK_ColorBLACK);
 
     paint.setAntiAlias(false);

-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list